Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(164)

Unified Diff: chrome/browser/component_updater/chrome_component_updater_configurator.cc

Issue 2710713004: Revert "Use the Windows MDM API to check if the machine is being managed." (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/chrome_browser_main_win.cc ('k') | chrome/browser/prefs/chrome_pref_service_factory.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/component_updater/chrome_component_updater_configurator.cc
diff --git a/chrome/browser/component_updater/chrome_component_updater_configurator.cc b/chrome/browser/component_updater/chrome_component_updater_configurator.cc
index b0e013d87d72ce5f9ab8f791180954bc2a742f40..2fccab7600c25f879debd3408cc1d674928a4498 100644
--- a/chrome/browser/component_updater/chrome_component_updater_configurator.cc
+++ b/chrome/browser/component_updater/chrome_component_updater_configurator.cc
@@ -149,13 +149,14 @@ std::string ChromeConfigurator::ExtraRequestParams() const {
std::string ChromeConfigurator::GetDownloadPreference() const {
#if defined(OS_WIN)
- // This group policy is supported only on Windows and only for enterprises.
- return base::win::IsEnterpriseManaged()
+ // This group policy is supported only on Windows and only for computers
+ // which are joined to a Windows domain.
+ return base::win::IsEnrolledToDomain()
? base::SysWideToUTF8(
GoogleUpdateSettings::GetDownloadPreference())
- : std::string();
+ : std::string("");
#else
- return std::string();
+ return std::string("");
#endif
}
« no previous file with comments | « chrome/browser/chrome_browser_main_win.cc ('k') | chrome/browser/prefs/chrome_pref_service_factory.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698